Struct amazon_sp_product_fees::models::fees_estimate::FeesEstimate
source · [−]pub struct FeesEstimate {
pub time_of_fees_estimation: String,
pub total_fees_estimate: Option<Box<MoneyType>>,
pub fee_detail_list: Option<Vec<FeeDetail>>,
}Expand description
FeesEstimate : The total estimated fees for an item and a list of details.
Fields
time_of_fees_estimation: StringThe time at which the fees were estimated. This defaults to the time the request is made.
total_fees_estimate: Option<Box<MoneyType>>fee_detail_list: Option<Vec<FeeDetail>>A list of other fees that contribute to a given fee.
Implementations
sourceimpl FeesEstimate
impl FeesEstimate
sourcepub fn new(time_of_fees_estimation: String) -> FeesEstimate
pub fn new(time_of_fees_estimation: String) -> FeesEstimate
The total estimated fees for an item and a list of details.